@@ -7,10 +7,11 @@ import json
 # from .helper import set_logger
 from aicmder.common import set_logger, LOG_VERBOSE
 import falcon
+from aicmder.service import CLIENT_PORT
 # 8s for timeout
 REQUEST_TIMEOUT = 8000  
 REQUEST_RETRIES = 3
-SERVER_ENDPOINT = "tcp://localhost:5555"
+SERVER_ENDPOINT = f"tcp://localhost:{CLIENT_PORT}"
 
 verbose = LOG_VERBOSE
 logging = set_logger(colored('SERVER_QUEUE', 'magenta'), verbose)
@@ -149,10 +150,11 @@ class Prediction:
         """Handles GET requests"""
         resp.status = falcon.HTTP_200  # This is the default status
         resp.content_type = falcon.MEDIA_TEXT  # Default is JSON, so override
-        resp.text = ('\nService status'
-                     '\nI am alive.\n'
-                     '\n'
-                     '    By Faith\n\n')
+        resp.text = ('OK')
+        # resp.text = ('\nService status'
+        #              '\nI am alive.\n'
+        #              '\n'
+        #              '    By Faith\n\n')
 
     
     @falcon.before(max_body(20 * 1024 * 1024))
